% P44mudim2.m noise and dimensionality-2
% Make 3 material images as function of number of photons
% COPYRIGHT:  Aprend Technology and Robert E. ALvarez, 2014. All rights reserved.
 
%% init vars
post_title = 'P44mudim2';
% modify this for your computer
dirname = ['L:\Projects\Blog\Posts\' post_title '\'];
addpath([dirname 'code']);
MakeBlogPostFileLists(post_title);

%% Prep data
   % x-ray spectrum
tube_voltage = 120; % kiloVolts  
[~,~,specdat] = XrayTubeSpectrumTasmip(tube_voltage,'number_spectrum','clipzeros');
     % clip even more zeros
specdat.specnum = specdat.specnum(10:end); % 10 was 'eyeballed' from data
specdat.egys = specdat.egys(10:end);
specdat.specnum_norm = specdat.specnum/trapz(specdat.egys,specdat.specnum);

material3 =  'adipose'; %'iodine'; % or   specify this before running script
tissues2 = {'soft_tissue','bone_cortical'}; % these are in every image
switch material3
     case 'adipose'
        tissues = [tissues2 'adipose'];
        specdat.mus = MusFromMaterials(tissues,specdat.egys);
        thicknesses = [1 .1 1]; % gm/cm^2 for tissues for this case
     case 'iodine'
        fracI = 0.01;
        tissues = [tissues2 'iodine'];
        muH2O = xraymu('H2O',specdat.egys);
        specdat.mus = [MusFromMaterials(tissues2,specdat.egys) ((1-fracI)*muH2O+fracI*xraymu('I',specdat.egys)) ];
        thicknesses = [1 .1 .1]; % gm/cm^2 for for tissues for this case
end
   % geometry: the box thicknesses are all set to one. 
   % For a specific case, multiply each column of ts_object by thickness
% init the simulated object -- define specs
nx = 256; ny = 256; % images width and height
zsiz = nx + 1i*ny; % dimensions of images
z1 = 1 + 1i;
   % boxes corners coords -- (image width)*(fractions of image width)
zcorners = nx*[ 
    .1*z1, .9*z1;
    .2*z1+0.4, 0.2*z1+0.4+ .2+.6i;
    .2*z1,.2*z1 + .2+.6i;
    ];
nmaterials = size(zcorners,1);  
tplanes = zeros(ny,nx,nmaterials); % one plane per material type
ts_object = zeros(nx*ny,nmaterials); % one row per pixel in image, columns are thicknesses of each type of material
for kmaterial = 1:nmaterials
    timg = Sim2D(zsiz,'rect',[zcorners(kmaterial,:),1]);
    tplanes(:,:,kmaterial) =  timg;
    ts_object(:,kmaterial) = timg(:);
end  
   % struct to save data  
geom.nx = nx;
geom.ny = ny;
geom.zcorners = zcorners;
geom.ts_object = ts_object;
geom.isobj = logical(ts_object);
geom.isair = ~any(geom.isobj,2);
geom.is_soft_only = geom.isobj(:,1) & (~any(geom.isobj(:,2:end),2));  

%% Compute the random image data
Nexponents = 3:7; 
Nphotons = 10.^(Nexponents); % number of photons incident per pixel, 
dat = MakeMudimImages(specdat,Nphotons,geom,thicknesses,'verbose');

%% display 3 basis funcs images vs. nphotons
fh = figure;
img2disp = dat.img;
nx = geom.nx;
ny = geom.ny;
labels = tissues;
do_number_labels = true;
imshow(img2disp',[-.5 1.5])
  % insert labels
ht = zeros(numel(Nphotons),1);
  % offsets for labels on images
xoffset = 80;
yoffset = .3;
for k = 1:numel(Nphotons)
    if k==1
        for ktissue = 1:nmaterials
            x = 120+(ktissue-1-.4)*ny;
            y = (k-.9)*ny;
            text(x,y,labels{ktissue},'fontsize',20,'color','k','interpreter','none','BackgroundColor','y');
        end
    end
    if do_number_labels
        if (Nexponents(k) - floor(Nexponents(k))) < eps
            ht(k) = text(xoffset,(k-yoffset)*ny,['10^{' num2str(Nexponents(k)) '}'],'fontsize',24,'color','k','BackgroundColor','y');
        else
            ht(k) = text(xoffset,(k-yoffset)*ny,num2str(Nphotons(k)),'fontsize',24,'color','k','BackgroundColor','y');
        end
    end
end

%% display 2 basis funcs images vs. nphotons
fh = figure;
image_type = 'Avector'; %'conv'; %
switch image_type
    case 'Avector';
        img2disp =  dat.img2;
        labels = {'soft tissue','','bone'};
        fname = '2Dimages';
    case 'conv';
        img2disp =  dat.imgsconv; %
        labels =  {'Nphotons','','AspaceOptPjn'}; 
        fname = '2Dimages_conv'; 
end
imshow(img2disp',[-.5 1.5])
  % insert labels
do_number_labels = true;
ht = zeros(numel(Nphotons),1);
  % offsets for labels on images
xoffset = 80 + 2*256;
yoffset = .3;
for k = 1:numel(Nphotons)
    if k==1
        koffset = 1;
        for ktissue = [1 3]
            x = 120+(koffset-1-.4)*ny;
            y = (k-.9)*ny;
            text(x,y,labels{ktissue},'fontsize',20,'color','k','interpreter','none','BackgroundColor','y');
            koffset = koffset + 1;
        end
    end
    if do_number_labels
        if (Nexponents(k) - floor(Nexponents(k))) < eps
            ht(k) = text(xoffset,(k-yoffset)*ny,['10^{' num2str(Nexponents(k)) '}'],'fontsize',24,'color','k','BackgroundColor','y');
        else
            ht(k) = text(xoffset,(k-yoffset)*ny,num2str(Nphotons(k)),'fontsize',24,'color','k','BackgroundColor','y');
        end    
    end    
end
